# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from dicomrtai.proto import hello_world_pb2 as dicomrtai_dot_proto_dot_hello__world__pb2


class HelloWorldStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.talk = channel.unary_unary(
            "/HelloWorld/talk",
            request_serializer=dicomrtai_dot_proto_dot_hello__world__pb2.Greeting.SerializeToString,
            response_deserializer=dicomrtai_dot_proto_dot_hello__world__pb2.Greeting.FromString,
        )


class HelloWorldServicer(object):
    """Missing associated documentation comment in .proto file."""

    def talk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_HelloWorldServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "talk": grpc.unary_unary_rpc_method_handler(
            servicer.talk,
            request_deserializer=dicomrtai_dot_proto_dot_hello__world__pb2.Greeting.FromString,
            response_serializer=dicomrtai_dot_proto_dot_hello__world__pb2.Greeting.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "HelloWorld", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class HelloWorld(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def talk(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HelloWorld/talk",
            dicomrtai_dot_proto_dot_hello__world__pb2.Greeting.SerializeToString,
            dicomrtai_dot_proto_dot_hello__world__pb2.Greeting.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
