# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dicomrtai/proto/hello_world.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="dicomrtai/proto/hello_world.proto",
    package="",
    syntax="proto3",
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n!dicomrtai/proto/hello_world.proto"\x1b\n\x08Greeting\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t2,\n\nHelloWorld\x12\x1e\n\x04talk\x12\t.Greeting\x1a\t.Greeting"\x00\x62\x06proto3',
)


_GREETING = _descriptor.Descriptor(
    name="Greeting",
    full_name="Greeting",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="content",
            full_name="Greeting.content",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=37,
    serialized_end=64,
)

DESCRIPTOR.message_types_by_name["Greeting"] = _GREETING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Greeting = _reflection.GeneratedProtocolMessageType(
    "Greeting",
    (_message.Message,),
    {
        "DESCRIPTOR": _GREETING,
        "__module__": "dicomrtai.proto.hello_world_pb2"
        # @@protoc_insertion_point(class_scope:Greeting)
    },
)
_sym_db.RegisterMessage(Greeting)


_HELLOWORLD = _descriptor.ServiceDescriptor(
    name="HelloWorld",
    full_name="HelloWorld",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=66,
    serialized_end=110,
    methods=[
        _descriptor.MethodDescriptor(
            name="talk",
            full_name="HelloWorld.talk",
            index=0,
            containing_service=None,
            input_type=_GREETING,
            output_type=_GREETING,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_HELLOWORLD)

DESCRIPTOR.services_by_name["HelloWorld"] = _HELLOWORLD

# @@protoc_insertion_point(module_scope)
